==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaUtilResourceBundleNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaUtilResourceBundleNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 458ff994c02a9e54 soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$java__5futil__5fResourceBundle__5fgetClassContext$ccbfc72d7e43ec4e(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$v$2efcb9ac38bed2f1(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaUtilResourceBundleNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaUtilResourceBundleNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 458ff994c02a9e54 soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$java__5futil__5fResourceBundle__5fgetClassContext$ccbfc72d7e43ec4e(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$method$v$2efcb9ac38bed2f1(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaUtilResourceBundleNative_H_ */
